// PoVRay 3.6/3.7 Scene File "Skybox_Demo1.pov"
// author: Friedrich A. Lohmueller, Jan-2010 
// homepage:  http://www.f-lohmueller.de
// email:  Friedrich.Lohmueller_at_t-online.de
//
// Demonstration for a skybox for SkyboxVierwer 
// adapted for skybox rendering for the SkyboxViewer by G.Platl

#include "colors.inc"
#include "textures.inc"                                                  
#include "glass.inc"

#include "shapes.inc"
#include "functions.inc"

#if ( version < 3.7 ) global_settings{ assumed_gamma 1.0 } #end
#default{ finish{ ambient 0.1 diffuse 0.9 }}

// camera -----------------------------------------------------------
#declare camLoc = <0, 1.2, 0>;
/*
camera{ location  camLoc 
        angle  70
        right     x*image_width/image_height
        look_at   <0.0, 1.2, 3.0> 
      }                    
*/
#include "SkyboxCamera.inc"

// sun --------------------------------------------------------------
light_source{<1500,2500,-2500> color White}

// add some light to sphere shadows ---------------------------------
light_source { camLoc Blue*0.1 }

// sky --------------------------------------------------------------
plane {<0,1,0>,1 hollow
       texture{ pigment{ bozo turbulence 0.76
                    color_map { [0.5 rgb <0.20, 0.20, 0.9>*0.9]
                                [0.6 rgb <1,1,1>]
                                [1.0 rgb <0.1,0.1,0.1>]}
                    scale 1.5 translate<0.5,0,11> }
           finish {ambient 1 diffuse 0} }
       scale 10000}

// fog --------------------------------------------------------------
fog{fog_type   2   distance 85  color rgb<1,0.99,0.9>
    fog_offset 0.1 fog_alt  2 turbulence 0.2}

// ground -----------------------------------------------------------
plane {<0,1,0>, 0  translate<0,-1.5,0>
       texture {pigment{color <0.7, 0.8, 0.7>}
                normal {bumps 0.8 scale <2.2, 1, 0.5>}
                finish {ambient 0.15 diffuse 0.85}}}

// sea water --------------------------------------------------------
plane{ <0,1,0>, 0
       texture {Green_Glass // pigment { rgb <0.5, 0.6, 0.5> }
                normal {ripples 0.3 scale 0.25
                        turbulence 0.75 translate< 1,0,2>}
                finish { ambient 0.05 diffuse 0.55
                         brilliance 3.0 phong 0.8 phong_size 120
                         reflection 0.4 }}
       interior{ I_Glass }}

//-------------------------------------------------------------------
//-------------------------- objects in scene -----------------------
//-------------------------------------------------------------------

//--4 stakes---------------------------------------------------------
#declare Stake_H = 1.75;
#declare Stake_R = 0.10;
#declare Stake =   // Pfahl
union{ // outer union 
 cylinder {<0,-Stake_H,0>,<0,Stake_H,0>,Stake_R translate<0,0,0>
   texture{ pigment{ spiral1 2
                     color_map{[0.0 White]
                               [0.5 White]
                               [0.5 rgb<1,0,0>]
                               [1.0 rgb<1,0,0>]}
                     rotate<90,0,0>
                     scale<1,0.3,1>}
            normal { bumps 0.3 scale 0.025}
            finish { phong 1 reflection 0.05}}}
 union{ // inner union 
   cylinder{<0,-0.05,0>,<0,0.05,0>,Stake_R+0.02 translate<0,Stake_H.0>}
   sphere{ <0,0,0>,Stake_R+0.02 translate<0,Stake_H+0.1,0>
           texture{ pigment{color White}
               //   normal {bumps 0.3 scale 0.025}
                    finish {  phong 1 reflection 0.05}
                  } 
         }// end sphere
   torus {1.0,0.1 scale 0.12  translate<0,Stake_H+0.01,0>}
   texture{ pigment{color White}
            normal {bumps 0.3 scale 0.025}
            finish {ambient 0.15 diffuse 0.85 phong 1 reflection 0.05}
          } // end texture
 } // end inner union 
} // end outer union 

//-------------------------------------------------------------------
object {Stake scale 1 rotate<0,0,0> translate <2,0,0>}
object {Stake scale 1 rotate<0,0,0> translate <0,0,2>}
object {Stake scale 1 rotate<0,0,0> translate <-2,0,0>}
object {Stake scale 1 rotate<0,0,0> translate <0,0,-2>}
//-------------------------------------------------------------------


//--------------------------------------------------------------------------
#include "Landing_Stage_000.inc"
//--------------------------------------------------------------------------
object{ Landing_Stage_000( 10, // Number_of_Elements_, //
                           0.50 , // Stage_Level_Height_, //
                           0.20 , // Stage_Level_End_Height, // starting lower
                           1.50 , // Post_Width_, //min.: Plank_Len_+Post_R_
                           2.10 , // Post_Distance_, // = Girder_Lenght_, // (in x)


                           1.00 , // Post_H_,
                           2.00 , // Post_Depth_, // under water
                           0.10 , // Post_R_,
                           0.16 , // Max_Height_Variation_, //
                           0.03 , // Max_R_Variation_ ,//
                           2.00 , // Max_Y_Rotation_ , //
                           31251, // Random_Seed, // (integer 0~64000)

                           1.25 , // Plank_Len_,
                           0.025, // Plank_D_,
                           0.18 , // Plank_Width_,
                           0.06 , // Plank_Between_,

                           1.70  , // Crossbeam_Length_,
                           0.12  , // Crossbeam_Height_,
                           0.05  , // Crossbeam_Diameter_,


                           0.10  , // Girder_Height_, // (in y)
                           0.06  , // Girder_Diameter_, // (in z )

                         )
        translate<-11,0,0>
        rotate<0,30,0>
      }
//--------------------------------------------------------------------------
